from django.apps import AppConfig


class DjsuperadminConfig(AppConfig):
    name = "djsuperadmin"
